==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/inputs/ServerExternalAdministratorArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin.inputs

import com.pulumi.azurenative.sql.inputs.ServerExternalAdministratorArgs.builder
import com.pulumi.azurenative.sql.kotlin.enums.AdministratorType
import com.pulumi.azurenative.sql.kotlin.enums.PrincipalType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Properties of a active directory administrator.
 * @property administratorType Type of the sever administrator.
 * @property azureADOnlyAuthentication Azure Active Directory only Authentication enabled.
 * @property login Login name of the server administrator.
 * @property principalType Principal Type of the sever administrator.
 * @property sid SID (object ID) of the server administrator.
 * @property tenantId Tenant ID of the administrator.
 */
public data class ServerExternalAdministratorArgs(
    public val administratorType: Output<Either<String, AdministratorType>>? = null,
    public val azureADOnlyAuthentication: Output<Boolean>? = null,
    public val login: Output<String>? = null,
    public val principalType: Output<Either<String, PrincipalType>>? = null,
    public val sid: Output<String>? = null,
    public val tenantId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sql.inputs.ServerExternalAdministratorArgs> {
    override fun toJava(): com.pulumi.azurenative.sql.inputs.ServerExternalAdministratorArgs =
        com.pulumi.azurenative.sql.inputs.ServerExternalAdministratorArgs.builder()
            .administratorType(
                administratorType?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .azureADOnlyAuthentication(azureADOnlyAuthentication?.applyValue({ args0 -> args0 }))
            .login(login?.applyValue({ args0 -> args0 }))
            .principalType(
                principalType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .sid(sid?.applyValue({ args0 -> args0 }))
            .tenantId(tenantId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ServerExternalAdministratorArgs].
 */
@PulumiTagMarker
public class ServerExternalAdministratorArgsBuilder internal constructor() {
    private var administratorType: Output<Either<String, AdministratorType>>? = null

    private var azureADOnlyAuthentication: Output<Boolean>? = null

    private var login: Output<String>? = null

    private var principalType: Output<Either<String, PrincipalType>>? = null

    private var sid: Output<String>? = null

    private var tenantId: Output<String>? = null

    /**
     * @param value Type of the sever administrator.
     */
    @JvmName("aqbtargcmnaeuowu")
    public suspend fun administratorType(`value`: Output<Either<String, AdministratorType>>) {
        this.administratorType = value
    }

    /**
     * @param value Azure Active Directory only Authentication enabled.
     */
    @JvmName("dnrxhxspqfqxrvxi")
    public suspend fun azureADOnlyAuthentication(`value`: Output<Boolean>) {
        this.azureADOnlyAuthentication = value
    }

    /**
     * @param value Login name of the server administrator.
     */
    @JvmName("wqogctfffuqymlar")
    public suspend fun login(`value`: Output<String>) {
        this.login = value
    }

    /**
     * @param value Principal Type of the sever administrator.
     */
    @JvmName("lolobhahegoqcjdk")
    public suspend fun principalType(`value`: Output<Either<String, PrincipalType>>) {
        this.principalType = value
    }

    /**
     * @param value SID (object ID) of the server administrator.
     */
    @JvmName("muhkfbfmrgxvdtmh")
    public suspend fun sid(`value`: Output<String>) {
        this.sid = value
    }

    /**
     * @param value Tenant ID of the administrator.
     */
    @JvmName("fbelcoywhtivbxsx")
    public suspend fun tenantId(`value`: Output<String>) {
        this.tenantId = value
    }

    /**
     * @param value Type of the sever administrator.
     */
    @JvmName("waemavfqlitiurbd")
    public suspend fun administratorType(`value`: Either<String, AdministratorType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.administratorType = mapped
    }

    /**
     * @param value Type of the sever administrator.
     */
    @JvmName("shbgixgqdlwwoyqi")
    public fun administratorType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AdministratorType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.administratorType = mapped
    }

    /**
     * @param value Type of the sever administrator.
     */
    @JvmName("rpxctlafdsqsybmm")
    public fun administratorType(`value`: AdministratorType) {
        val toBeMapped = Either.ofRight<String, AdministratorType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.administratorType = mapped
    }

    /**
     * @param value Azure Active Directory only Authentication enabled.
     */
    @JvmName("aokifvvmjnbeholh")
    public suspend fun azureADOnlyAuthentication(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureADOnlyAuthentication = mapped
    }

    /**
     * @param value Login name of the server administrator.
     */
    @JvmName("phnilsihudbwkkpf")
    public suspend fun login(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.login = mapped
    }

    /**
     * @param value Principal Type of the sever administrator.
     */
    @JvmName("jmjmlepyythqkuyn")
    public suspend fun principalType(`value`: Either<String, PrincipalType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.principalType = mapped
    }

    /**
     * @param value Principal Type of the sever administrator.
     */
    @JvmName("xwecjqocgsgaqjia")
    public fun principalType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, PrincipalType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.principalType = mapped
    }

    /**
     * @param value Principal Type of the sever administrator.
     */
    @JvmName("mwbgagcbrjvecghq")
    public fun principalType(`value`: PrincipalType) {
        val toBeMapped = Either.ofRight<String, PrincipalType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.principalType = mapped
    }

    /**
     * @param value SID (object ID) of the server administrator.
     */
    @JvmName("hjoecxcnnwbmvxuy")
    public suspend fun sid(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sid = mapped
    }

    /**
     * @param value Tenant ID of the administrator.
     */
    @JvmName("ikvovfwdbfkcmaxn")
    public suspend fun tenantId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tenantId = mapped
    }

    internal fun build(): ServerExternalAdministratorArgs = ServerExternalAdministratorArgs(
        administratorType = administratorType,
        azureADOnlyAuthentication = azureADOnlyAuthentication,
        login = login,
        principalType = principalType,
        sid = sid,
        tenantId = tenantId,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/inputs/ServerExternalAdministratorArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin.inputs

import com.pulumi.azurenative.sql.inputs.ServerExternalAdministratorArgs.builder
import com.pulumi.azurenative.sql.kotlin.enums.AdministratorType
import com.pulumi.azurenative.sql.kotlin.enums.PrincipalType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Properties of a active directory administrator.
 * @property administratorType Type of the sever administrator.
 * @property azureADOnlyAuthentication Azure Active Directory only Authentication enabled.
 * @property login Login name of the server administrator.
 * @property principalType Principal Type of the sever administrator.
 * @property sid SID (object ID) of the server administrator.
 * @property tenantId Tenant ID of the administrator.
 */
public data class ServerExternalAdministratorArgs(
    public val administratorType: Output<Either<String, AdministratorType>>? = null,
    public val azureADOnlyAuthentication: Output<Boolean>? = null,
    public val login: Output<String>? = null,
    public val principalType: Output<Either<String, PrincipalType>>? = null,
    public val sid: Output<String>? = null,
    public val tenantId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sql.inputs.ServerExternalAdministratorArgs> {
    override fun toJava(): com.pulumi.azurenative.sql.inputs.ServerExternalAdministratorArgs =
        com.pulumi.azurenative.sql.inputs.ServerExternalAdministratorArgs.builder()
            .administratorType(
                administratorType?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .azureADOnlyAuthentication(azureADOnlyAuthentication?.applyValue({ args0 -> args0 }))
            .login(login?.applyValue({ args0 -> args0 }))
            .principalType(
                principalType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .sid(sid?.applyValue({ args0 -> args0 }))
            .tenantId(tenantId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ServerExternalAdministratorArgs].
 */
@PulumiTagMarker
public class ServerExternalAdministratorArgsBuilder internal constructor() {
    private var administratorType: Output<Either<String, AdministratorType>>? = null

    private var azureADOnlyAuthentication: Output<Boolean>? = null

    private var login: Output<String>? = null

    private var principalType: Output<Either<String, PrincipalType>>? = null

    private var sid: Output<String>? = null

    private var tenantId: Output<String>? = null

    /**
     * @param value Type of the sever administrator.
     */
    @JvmName("vkccnpmuqndunpsv")
    public suspend fun administratorType(`value`: Output<Either<String, AdministratorType>>) {
        this.administratorType = value
    }

    /**
     * @param value Azure Active Directory only Authentication enabled.
     */
    @JvmName("uoryclghnesjxmel")
    public suspend fun azureADOnlyAuthentication(`value`: Output<Boolean>) {
        this.azureADOnlyAuthentication = value
    }

    /**
     * @param value Login name of the server administrator.
     */
    @JvmName("jvyopurjtcqhypjl")
    public suspend fun login(`value`: Output<String>) {
        this.login = value
    }

    /**
     * @param value Principal Type of the sever administrator.
     */
    @JvmName("pcyqblhjdwlgibnv")
    public suspend fun principalType(`value`: Output<Either<String, PrincipalType>>) {
        this.principalType = value
    }

    /**
     * @param value SID (object ID) of the server administrator.
     */
    @JvmName("wyaaxqebpojcqxtt")
    public suspend fun sid(`value`: Output<String>) {
        this.sid = value
    }

    /**
     * @param value Tenant ID of the administrator.
     */
    @JvmName("ntmpkyvjnbjwdhsc")
    public suspend fun tenantId(`value`: Output<String>) {
        this.tenantId = value
    }

    /**
     * @param value Type of the sever administrator.
     */
    @JvmName("vcmghruvolxvsugy")
    public suspend fun administratorType(`value`: Either<String, AdministratorType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.administratorType = mapped
    }

    /**
     * @param value Type of the sever administrator.
     */
    @JvmName("tkpbkmaiurtqbxbd")
    public fun administratorType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AdministratorType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.administratorType = mapped
    }

    /**
     * @param value Type of the sever administrator.
     */
    @JvmName("dfulgvbhpvtfgtgy")
    public fun administratorType(`value`: AdministratorType) {
        val toBeMapped = Either.ofRight<String, AdministratorType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.administratorType = mapped
    }

    /**
     * @param value Azure Active Directory only Authentication enabled.
     */
    @JvmName("vjxmmxavhyqnsxun")
    public suspend fun azureADOnlyAuthentication(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureADOnlyAuthentication = mapped
    }

    /**
     * @param value Login name of the server administrator.
     */
    @JvmName("vgadplnjsrmweeyr")
    public suspend fun login(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.login = mapped
    }

    /**
     * @param value Principal Type of the sever administrator.
     */
    @JvmName("tegqbhrktlfemsma")
    public suspend fun principalType(`value`: Either<String, PrincipalType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.principalType = mapped
    }

    /**
     * @param value Principal Type of the sever administrator.
     */
    @JvmName("jjsicrujsafybqjr")
    public fun principalType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, PrincipalType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.principalType = mapped
    }

    /**
     * @param value Principal Type of the sever administrator.
     */
    @JvmName("vrekdkmlmuhngdpk")
    public fun principalType(`value`: PrincipalType) {
        val toBeMapped = Either.ofRight<String, PrincipalType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.principalType = mapped
    }

    /**
     * @param value SID (object ID) of the server administrator.
     */
    @JvmName("jxbfdofrnilafsrn")
    public suspend fun sid(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sid = mapped
    }

    /**
     * @param value Tenant ID of the administrator.
     */
    @JvmName("nqflcdnhtiggfbqh")
    public suspend fun tenantId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tenantId = mapped
    }

    internal fun build(): ServerExternalAdministratorArgs = ServerExternalAdministratorArgs(
        administratorType = administratorType,
        azureADOnlyAuthentication = azureADOnlyAuthentication,
        login = login,
        principalType = principalType,
        sid = sid,
        tenantId = tenantId,
    )
}
